@@ -9,7 +9,7 @@ use Mojo::File;
 use Mojo::Log;
 use WWW::Crawler::Mojo::ScraperUtil qw{resolve_href guess_encoding};
 use Encode;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 my $html_type_regex = qr{^(text|application)/(html|xml|xhtml)};
 my $css_type_regex = qr{^text/css$};
@@ -244,12 +244,12 @@ User Agent      : @{[ $self->ua_name ]}
 EOF
     say $content;
 
-    if ($this->log) {
+    if ($self->log) {
         $self->log->append($content);
         say <<EOF;
 This could take a while. You can run the following command on another shell to track the status:
 
-  tail -f @{[ $this->log ]}
+  tail -f @{[ $self->log ]}
 EOF
     }
 }
